@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import print_function
 from itertools import combinations
 from io import BytesIO, StringIO
 from previsionio.usecase_config import UsecaseState
@@ -121,10 +120,7 @@ class Dataset(ApiResource):
             PrevisionException: If the dataset does not exist
             requests.exceptions.ConnectionError: Error processing the request
         """
-        resp = client.request(endpoint='/{}/{}'.format(self.resource, self.id),
-                              method=requests.delete,
-                              message_prefix='Dataset delete')
-        return resp
+        super().delete()
 
     def start_embedding(self):
         """Starts the embeddings analysis of the dataset from the actual [client] workspace
@@ -315,8 +311,14 @@ class Dataset(ApiResource):
 
         create_json = parse_json(create_resp)
         url = '/{}/{}'.format(cls.resource, create_json['_id'])
-        event_tuple = previsionio.utils.EventTuple('DATASET_UPDATE', 'describe_state', 'done',
-                                                   [('ready', 'failed'), ('drift', 'failed')])
+        event_tuple = previsionio.utils.EventTuple('DATASET_UPDATE',
+                                                   [('copy_state', 'done'),
+                                                       ('describe_state', 'done'),
+                                                       ('drift_state', 'done')],
+                                                   [('copy_state', 'failed'),
+                                                       ('describe_state', 'failed'),
+                                                       ('drift_state', 'failed'),
+                                                       ('embeddings_state', 'failed')])
         assert pio.client.event_manager is not None
         pio.client.event_manager.wait_for_event(create_json['_id'],
                                                 cls.resource,
@@ -365,10 +367,7 @@ class DatasetImages(ApiResource):
             PrevisionException: If the dataset images does not exist
             requests.exceptions.ConnectionError: Error processing the request
         """
-        resp = client.request(endpoint='/{}/{}'.format(self.resource, self.id),
-                              method=requests.delete,
-                              message_prefix='Image folder delete')
-        return resp
+        super().delete()
 
     @classmethod
     def list(cls, project_id: str, all: bool = True):
@@ -431,7 +430,7 @@ class DatasetImages(ApiResource):
         pio.client.event_manager.wait_for_event(create_json['_id'],
                                                 cls.resource,
                                                 previsionio.utils.EventTuple(
-                                                    'FOLDER_UPDATE', 'state', 'done', [('state', 'failed')]),
+                                                    'FOLDER_UPDATE'),
                                                 specific_url=url)
 
         dset_resp = client.request(url, method=requests.get, message_prefix='Image folder loading')
