@@ -1,4 +1,3 @@
-from typing import List
 import requests
 
 from .api_resource import ApiResource
@@ -7,15 +6,15 @@ from .utils import PrevisionException, EventTuple, zip_to_pandas
 
 
 class ValidationPrediction(ApiResource):
-    """ Prediction object represent usecase prediction bulk resource that will be explored by Prevision.io platform.
-
+    """ A prediction object that represents a usecase bulk prediction resource which can be explored on the Prevision.io
+    platform.
     """
 
-    resource = 'validation-prediction'
-
-    def __init__(self, _id: str,usecase_id: str, usecase_version_id: str, project_id: str,  state='running' , model_id=None, model_name=None,
-                 dataset_id=None, download_available=False, score=None, duration=None, predictions_count=None, **kwargs):
+    resource = 'validation-predictions'
 
+    def __init__(self, _id: str, usecase_id: str, usecase_version_id: str, project_id: str, state='running',
+                 model_id=None, model_name=None, dataset_id=None, download_available=False, score=None, duration=None,
+                 predictions_count=None, **kwargs):
         self._id = _id
         self.usecase_id = usecase_id
         self.usecase_version_id = usecase_version_id
@@ -34,10 +33,10 @@ class ValidationPrediction(ApiResource):
         """Get a prediction from the platform by its unique id.
 
         Args:
-            _id (str): Unique id of the usecase prediction bulk to retrieve
+            _id (str): Unique id of the usecase bulk prediction to retrieve
 
         Returns:
-            :class:`.Prediction`: Fetched prediction
+            :class:`.ValidationPrediction`: The fetched prediction
 
         Raises:
             PrevisionException: Any error while fetching data from the platform
@@ -54,16 +53,16 @@ class ValidationPrediction(ApiResource):
         """Delete a prediction from the platform by its unique id.
 
         Raises:
-            PrevisionException: Any error while fetching data from the platform
-                or parsing result
+            PrevisionException: If the prediction images does not exist
+            requests.exceptions.ConnectionError: Error processing the request
         """
-        response = client.request(endpoint='/{}/{}'.format(self.resource, self._id),
-                                  method=requests.delete,
-                                  message_prefix='Prediction deletion')
-        return response
+        super().delete()
 
     def get_result(self):
-        """Delete a prediction from the platform by its unique id.
+        """Get the prediction result.
+
+        Returns:
+            ``pd.DataFrame``: Prediction results dataframe
 
         Raises:
             PrevisionException: Any error while fetching data from the platform
@@ -87,20 +86,19 @@ class ValidationPrediction(ApiResource):
         specific_url = '/{}/{}'.format(self.resource, self._id)
         client.event_manager.wait_for_event(self._id,
                                             specific_url,
-                                            EventTuple('PREDICTION_UPDATE', 'state', 'done', [('state', 'failed')]),
+                                            EventTuple('PREDICTION_UPDATE'),
                                             specific_url=specific_url)
 
 
 class DeploymentPrediction(ApiResource):
-    """ Prediction object represent usecase prediction bulk resource that will be explored by Prevision.io platform.
-
+    """ A prediction object that represents a deployed usecase bulk prediction resource which can be explored on the
+    Prevision.io platform.
     """
 
     resource = 'deployment-predictions'
 
     def __init__(self, _id: str, project_id: str, deployment_id: str, state='running', main_model_id=None,
                  challenger_model_id=None, **kwargs):
-
         self._id = _id
         self.project_id = project_id
         self.deployment_id = deployment_id
@@ -108,8 +106,6 @@ class DeploymentPrediction(ApiResource):
         self.challenger_model_id = challenger_model_id
         self._state = state
         for k, v in kwargs.items():
-            #print("k============", k)
-            #print("v============", v)
             self.__setattr__(k, v)
 
     @classmethod
@@ -117,10 +113,10 @@ class DeploymentPrediction(ApiResource):
         """Get a prediction from the platform by its unique id.
 
         Args:
-            _id (str): Unique id of the usecase prediction bulk to retrieve
+            _id (str): Unique id of the deployed usecase bulk prediction to retrieve
 
         Returns:
-            :class:`.DeploymentPrediction`: Fetched prediction
+            :class:`.DeploymentPrediction`: The fetched prediction
 
         Raises:
             PrevisionException: Any error while fetching data from the platform
@@ -129,13 +125,24 @@ class DeploymentPrediction(ApiResource):
         return cls(**super()._from_id(specific_url='/{}/{}'.format(cls.resource, _id)))
 
     def get_result(self):
+        """Get the prediction result of the main model.
+
+        Returns:
+            ``pd.DataFrame``: Prediction results dataframe
+
+        Raises:
+            PrevisionException: Any error while fetching data from the platform
+                or parsing result
+        """
         specific_url = '/{}/{}'.format(self.resource, self._id)
         client.event_manager.wait_for_event(self._id,
                                             specific_url,
-                                            EventTuple('DEPLOYMENT_PREDICTION_UPDATE', 'main_model_prediction_state', 'done',
-                                                       [('main_model_prediction_state', 'failed')]),
+                                            EventTuple(
+                                                'DEPLOYMENT_PREDICTION_UPDATE',
+                                                ('main_model_prediction_state', 'done'),
+                                                [('main_model_prediction_state', 'failed')]),
                                             specific_url=specific_url)
-        #
+
         url = '/{}/{}/download'.format(self.resource, self._id)
         pred_response = client.request(url,
                                        method=requests.get,
@@ -144,16 +151,27 @@ class DeploymentPrediction(ApiResource):
         return zip_to_pandas(pred_response)
 
     def get_challenger_result(self):
+        """Get the prediction result of the challenger model.
+
+        Returns:
+            ``pd.DataFrame``: Prediction results dataframe
+
+        Raises:
+            PrevisionException: Any error while fetching data from the platform
+                or parsing result
+        """
         if self.challenger_model_id is None:
             PrevisionException('Challenger data not availbale for this prediction')
-        specific_url = '/{}/{}'.format(self.resource, self._id)
+        specific_url = '/{}/{}'.format(self.resource, self.challenger_model_id)
         client.event_manager.wait_for_event(self._id,
                                             specific_url,
-                                            EventTuple('DEPLOYMENT_PREDICTION_UPDATE', 'challenger_model_prediction_state', 'done',
-                                                       [('challenger_model_prediction_state', 'failed')]),
+                                            EventTuple(
+                                                'DEPLOYMENT_PREDICTION_UPDATE',
+                                                ('challenger_model_prediction_state', 'done'),
+                                                [('challenger_model_prediction_state', 'failed')]),
                                             specific_url=specific_url)
-        #
-        url = '/{}/{}/download'.format(self.resource, self._id)
+
+        url = '/{}/{}/download'.format(self.resource, self.challenger_model_id)
         pred_response = client.request(url,
                                        method=requests.get,
                                        message_prefix='Predictions download')
