@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
-from __future__ import print_function
 import json
-from previsionio import metrics
 from previsionio.model import Model
 from typing import Dict, List, Union
 import pandas as pd
@@ -234,21 +232,19 @@ class BaseUsecaseVersion(ApiResource):
         assert pio.client.event_manager is not None
         pio.client.event_manager.wait_for_event(self.resource_id,
                                                 self.resource,
-                                                EventTuple('USECASE_VERSION_UPDATE', 'state',
-                                                           'done', [('state', 'failed')]),
+                                                EventTuple('USECASE_VERSION_UPDATE'),
                                                 specific_url=events_url)
         logger.info('[Usecase] stopping:' + '  '.join(str(k) + ': ' + str(v)
                                                       for k, v in parse_json(response).items()))
 
-    # def delete(self):
-    #     """ Delete a usecase from the actual [client] workspace.
-    #
-    #     Returns:
-    #         dict: Deletion process results
-    #     """
-    #     response = client.request(endpoint='/usecases/{}'.format(self._id),
-    #                               method=requests.delete)
-    #     return (json.loads(response.content.decode('utf-8')))
+    def delete(self):
+        """Delete a usecase version from the actual [client] workspace.
+
+        Raises:
+            PrevisionException: If the usecase version does not exist
+            requests.exceptions.ConnectionError: Error processing the request
+        """
+        super().delete()
 
     def wait_until(self, condition, raise_on_error: bool = True, timeout: float = config.default_timeout):
         """ Wait until condition is fulfilled, then break.
@@ -657,7 +653,8 @@ class ClassicUsecaseVersion(BaseUsecaseVersion):
                 predictions, if necessary
 
         Returns:
-            ``pd.DataFrame``: Predictions as a ``pandas`` dataframe
+            :class:`previsionio.prediction.ValidationPrediction`: The registered prediction object in the current
+            workspace
         """
 
         best = self.best_model
@@ -679,7 +676,7 @@ class ClassicUsecaseVersion(BaseUsecaseVersion):
                 (default: ``False``)
 
         Returns:
-            tuple(pd.DataFrame, str): Prediction data (as ``pandas`` dataframe) and prediction job ID.
+            ``pd.DataFrame``: Prediction results dataframe
         """
 
         best = self.best_model
